@@ -12,7 +12,16 @@ def test_plugin(testdir):
             trip_created = 'trip_created'
             device_created = 'device.created'
             vehicle_created = 'vehicle_created'
-    """
+    """,
+        protobuf_factory="""
+        from hedwig.testing.factories.protobuf import ProtobufMessageFactory as BaseProtobufMessageFactory
+        from tests.schemas.protos import protobuf_pb2
+
+
+        class ProtobufMessageFactory(BaseProtobufMessageFactory):
+            class Params:
+                protobuf_schema_module = protobuf_pb2
+    """,
     )
 
     testdir.makeconftest(
@@ -22,9 +31,8 @@ def test_plugin(testdir):
         import pytest
 
         import hedwig.conf
-        from hedwig import models
-        from hedwig.models import Message
-        from hedwig.testing.factories import MessageFactory
+        from hedwig.models import Message, _validator
+        from hedwig.testing.config import unconfigure
 
         from models import MessageType
 
@@ -56,17 +64,37 @@ def test_plugin(testdir):
         def _message_type():
             return MessageType.trip_created
 
-        @pytest.fixture(name='message_data')
-        def _message_data(message_type):
-            return MessageFactory.build(msg_type=message_type)
+        @pytest.fixture(
+            name='message_factory', params=['jsonschema', 'protobuf'], ids=['jsonschema', 'protobuf'],
+        )
+        def _message_factory(request, settings):
+            if request.param == 'jsonschema':
+                settings.HEDWIG_DATA_VALIDATOR_CLASS = 'hedwig.validators.jsonschema.JSONSchemaValidator'
 
-        @pytest.fixture
-        def message(message_data):
-            return Message(message_data)
+                try:
+                    from hedwig.validators.jsonschema import JSONSchemaMessageFactory  # noqa
+
+                    yield JSONSchemaMessageFactory()
+                except ImportError:
+                    pytest.skip("JSON Schema validator not importable")
+
+            if request.param == 'protobuf':
+                settings.HEDWIG_DATA_VALIDATOR_CLASS = 'hedwig.validators.protobuf.ProtobufValidator'
+
+                try:
+                    from protobuf_factory import ProtobufValidator  # noqa
+
+                    yield ProtobufValidator()
+                except ImportError:
+                    pytest.skip("Protobuf validator not importable")
+
+        @pytest.fixture(name='message')
+        def _message(message_factory, message_type):
+            return message_factory(msg_type=message_type)
 
         @pytest.fixture(name='other_message_data')
-        def _other_message_data(message_type):
-            return MessageFactory.build(msg_type=message_type)
+        def _other_message_data(message_factory, message_type):
+            return message_factory.build(msg_type=message_type)
 
         @pytest.fixture
         def settings():
@@ -77,18 +105,14 @@ def test_plugin(testdir):
                 def __getattr__(self, name):
                     return overrides.get(name, getattr(original_module, name))
 
+            unconfigure()
             hedwig.conf.settings._user_settings = Wrapped()
-            hedwig.conf.settings.clear_cache()
-            # in case a test overrides HEDWIG_DATA_VALIDATOR_CLASS
-            models._validator = None
 
             try:
                 yield hedwig.conf.settings._user_settings
             finally:
+                unconfigure()
                 hedwig.conf.settings._user_settings = original_module
-                hedwig.conf.settings.clear_cache()
-                # in case a test overrides HEDWIG_DATA_VALIDATOR_CLASS
-                models._validator = None
     """
     )
 
@@ -114,18 +138,18 @@ def test_plugin(testdir):
             # check with string message type
             mock_hedwig_publish.assert_message_not_published(message.type, data=other_message_data)
             mock_hedwig_publish.assert_message_published(
-                message.type, data=message.data, version=message.data_schema_version)
+                message.type, data=message.data, version=message.version)
 
 
         def test_mock_hedwig_publish_published(mock_hedwig_publish, message):
             message.publish()
             mock_hedwig_publish.assert_message_published(
-                message.type, data=message.data, version=message.data_schema_version)
+                message.type, data=message.data, version=message.version)
 
 
         def test_mock_hedwig_publish_published_without_checking_data(mock_hedwig_publish, message):
             message.publish()
-            mock_hedwig_publish.assert_message_published(message.type, version=message.data_schema_version)
+            mock_hedwig_publish.assert_message_published(message.type, version=message.version)
     """
     )
 
@@ -133,4 +157,4 @@ def test_plugin(testdir):
     result = testdir.runpytest().parseoutcomes()
 
     # check that all tests passed
-    assert result.get('passed', 0) + result.get('skipped', 0) == 10
+    assert result.get('passed', 0) + result.get('skipped', 0) == 18
